#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location    : http://www.rarlab.com/rar/
# last revised       : 11.02.2011

softname='unrar'
softversion='4.0.6'
packageversion='70.1'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/unrarsrc-$softversion.tar.gz"
src="$buildir/$softname"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://www.rarlab.com/rar/unrarsrc-$softversion.tar.gz

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/bin
mkdir -p $dest/usr/libexec
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
     |-----handy-ruler------------------------------------------------------|
unrar: RAR files extractor and viewer
unrar: 
unrar: Portable UnRAR version 
unrar: UnRAR is a freeware made available by RARLAB 
unrar: 
unrar: 
unrar: 
unrar: 
unrar: 
unrar:
unrar: 
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src

# building
CFLAGS="-O2 -march=$arch -mtune=$cpu" make -f makefile.unix
cp unrar $dest/usr/libexec


# add 'default' files
    cp -a \
      license.txt readme.txt \
      $dest/usr/doc/$softname-$softversion

cat <<"EOF" > $dest/usr/bin/unrar
#!/bin/bash
# Launcher helper for the unrar utility - Jean-Philippe Guillemin <jp.guillemin@free.fr>
[ $# -eq 1 ] && exec /usr/libexec/unrar e "$@"
exec /usr/libexec/unrar "$@" 
EOF

chmod 755 $dest/usr/bin/unrar

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# put the ZenWalk build in the right directory
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "gcc-g++" > $package.dep

# generate source file
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/ap/unrar/source/build-unrar.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
